pub struct CdpArray<T: RDH, const CAP: usize> { /* private fields */ }
The vector-like wrapper struct for CDPs

Implementations

source

impl<T: RDH, const CAP: usize> CdpArray<T, CAP>

source

pub fn new() -> Self

Construct a new, empty CdpArray<T: RDH>.

source

pub const fn new_const() -> Self

Construct a new, empty CdpArray<T: RDH> with at least the specified capacity.

The array will be able to hold at least capacity elements.

Examples
let mut arrvec = CdpArray::<RdhCru, 10>::new_const();
assert!(arrvec.len() == 0);
source

pub fn push(&mut self, rdh: T, payload: Vec<u8>, mem_pos: u64)

Appends an RDH, payload, and memory position to the back of the CdpArray

source

pub fn push_tuple(&mut self, cdp_tuple: (T, Vec<u8>, u64))

Convenience method to push a tuple of (RDH, payload, mem_pos)

Removes the need to destructure the tuple before pushing

source

pub fn len(&self) -> usize

Get the length of the CdpArray, corresponding to the number of CDPs

source

pub fn is_empty(&self) -> bool

Check if the CdpArray is empty

source

pub fn clear(&mut self)

Clear the CdpArray, removing all elements.

source

pub fn rdh_slice(&self) -> &[T]

Get a borrowed slice of the RDHs

source

pub fn rdh_mem_pos_slice(&self) -> &[u64]

Get a borrowed slice of the memory positions

source

pub fn iter(&self) -> CdpArrayIter<'_, T, CAP>

Create an iterator over the CdpArray that yields borrowed references to the CDPs