Module alice_protocol_reader::input_scanner
source · Expand description
Contains the InputScanner & ScanCDP trait, responsible for reading and forwarding input data.
The InputScanner implements the ScanCDP trait.
Structs
- Scans data read through a BufferedReaderWrapper, tracks the position in memory and sends InputStatType through the
flume::Sender<InputStatType>channel.