This module contains all struct definitions for the words that are used in supported data formats.

Re-exports

  • pub use rdh0::Rdh0;
  • pub use rdh_cru::RdhCru;
  • pub use rdh_cru::V6;
  • pub use rdh_cru::V7;

Modules

  • Module containing macros related to protocol words.
  • Struct definition of the RDH subword RDH0
  • Struct definition of the RDH subword RDH1
  • Struct definition of the RDH subword RDH2
  • Struct definition of the RDH subword RDH3
  • Contains the definition of the RDH CRU.
  • Contains test data for testing functionality on a RDH CRU.

Constants

Traits

  • Trait used to convert a struct to a byte slice. All structs that are used to represent a full GBT word (not sub RDH words) must implement this trait.
  • Trait that all RDH words must implement
  • Trait for accessing fields of a RDH word of the RDH CRU flavor.
  • That all RDH subwords words must implement
  • Trait to Serialize/Deserialise (serde) RDH words.