Contains the InputStatType enum for which kind of statistics are gathered, and the Stats struct for tracking and reporting statistics about the input data.

Structs

  • Struct for tracking and reporting statistics about the input data.

Enums