pub struct Stats { /* private fields */ }
Struct for tracking and reporting statistics about the input data.

Implementations

source

impl Stats

source

pub fn new(reporter: Sender<InputStatType>) -> Self

Create a new Stats instance.

Attempt to add a link id to the observed links (is only added if not already present in the list).

source

pub fn try_add_fee_id(&mut self, fee_id: u16)

Attempt to add a FEE ID to the observed FEE IDs (is only added if not already present in the list).

source

pub fn rdh_seen(&mut self)

Increment the RDH seen counter..

source

pub fn rdh_filtered(&mut self)

Increment the RDH filtered counter.

source

pub fn add_payload_size(&mut self, payload_size: u16)

Add a payload size to the total payload size seen.

source

pub fn flush_stats(&mut self)

Flush the stats to the reporter channel (sends all the current stats).