Module alice_protocol_reader::bufreader_wrapper
source · Traits
- Allows a stdin reader to be used in the same way as a file reader, by making it possible to seek (skip data) Formally it it requires implementing Seek but practically only the seek_relative method is used and as such all other methods can be left unimplemented (return not implemented error)