Module alice_protocol_reader::rdh
source · Expand description
This module contains all struct definitions for the words that are used in supported data formats.
Re-exports
Modules
- Module containing macros related to protocol words.
- Struct definition of the
RDHsubwordRDH0 - Struct definition of the
RDHsubwordRDH1 - Struct definition of the
RDHsubwordRDH2 - Struct definition of the
RDHsubwordRDH3 - Contains the definition of the RDH CRU.
- Contains test data for testing functionality on a RDH CRU.
Constants
- The size of a RDH-CRU word in bytes
Traits
- Trait used to convert a struct to a byte slice. All structs that are used to represent a full GBT word (not sub RDH words) must implement this trait.
- Trait that all RDH words must implement
- Trait for accessing fields of a RDH word of the RDH CRU flavor.
- That all RDH
subwordswords must implement - Trait to Serialize/Deserialise (serde) RDH words.